@@ -8,10 +8,10 @@ This example displays methods for visualizing scalar fields.
 import matplotlib.pyplot as plt
 import numpy as np
 
-from pde import CylindricalGrid, ScalarField
+from pde import CylindricalSymGrid, ScalarField
 
 # create a scalar field with some noise
-grid = CylindricalGrid(7, [0, 4 * np.pi], 64)
+grid = CylindricalSymGrid(7, [0, 4 * np.pi], 64)
 data = ScalarField.from_expression(grid, "sin(z) * exp(-r / 3)")
 data += 0.05 * ScalarField.random_normal(grid)
 
@@ -27,3 +27,4 @@ smoothed.plot(ax=axes[1, 0], title="Smoothed field")
 projected.plot(ax=axes[0, 1], title="Projection on axial coordinate")
 sliced.plot(ax=axes[1, 1], title="Slice of smoothed field at $z=1$")
 plt.subplots_adjust(hspace=0.8)
+plt.show()
