@@ -19,9 +19,9 @@ class KuramotoSivashinskyPDE(PDEBase):
 
     def evolution_rate(self, state, t=0):
         """implement the python version of the evolution equation"""
-        state_lap = state.laplace(bc="natural")
-        state_lap2 = state_lap.laplace(bc="natural")
-        state_grad = state.gradient(bc="natural")
+        state_lap = state.laplace(bc="auto_periodic_neumann")
+        state_lap2 = state_lap.laplace(bc="auto_periodic_neumann")
+        state_grad = state.gradient(bc="auto_periodic_neumann")
         return -state_grad.to_scalar("squared_sum") / 2 - state_lap - state_lap2
 
 
