@@ -58,8 +58,8 @@ class Tensor2Field(DataFieldBase):
             label (str, optional):
                 Name of the field
             dtype (numpy dtype):
-                The data type of the field. All the numpy dtypes are supported. If
-                omitted, it will be determined from `data` automatically.
+                The data type of the field. If omitted, it will be determined from
+                `data` automatically.
         """
         from ..tools.expressions import ScalarExpression
 
@@ -78,7 +78,9 @@ class Tensor2Field(DataFieldBase):
         points = {name: grid.cell_coords[..., i] for i, name in enumerate(grid.axes)}
 
         # evaluate all vector components at all points
-        data = [[None] * grid.dim for _ in range(grid.dim)]
+        data: List[List[Optional[np.ndarray]]] = [
+            [None] * grid.dim for _ in range(grid.dim)
+        ]
         for i in range(grid.dim):
             for j in range(grid.dim):
                 expr = ScalarExpression(expressions[i][j], signature=grid.axes)
@@ -342,6 +344,10 @@ class Tensor2Field(DataFieldBase):
                 Optional scalar field to which the  result is written.
             label (str, optional):
                 Name of the returned field
+            **kwargs:
+                Additional arguments affecting how the operator behaves. For instance,
+                the argument `normal_bcs` can be used to control whether boundary
+                conditions only specify normal components or not.
 
         Returns:
             :class:`~pde.fields.vectorial.VectorField`: result of applying the operator
