@@ -37,6 +37,11 @@ def test_collections():
     assert fields.data.shape == (7, 3, 4)
     assert isinstance(str(fields), str)
 
+    fields2 = FieldCollection.from_dict({"s": sf, "v": vf, "t": tf}, copy_fields=True)
+    assert fields == fields2
+    assert fields2.labels == ["s", "v", "t"]
+    assert not np.shares_memory(fields[0].data, fields2[0].data)
+
     fields.data[:] = 0
     np.testing.assert_allclose(sf.data, 0)
     np.testing.assert_allclose(vf.data, 0)
