@@ -11,7 +11,6 @@ from pde.fields.base import FieldBase
 from pde.fields.scalar import ScalarField
 from pde.fields.tests.fixtures import iter_grids
 from pde.grids import CartesianGrid, PolarSymGrid, UnitGrid, boundaries
-from pde.grids.cartesian import CartesianGridBase
 from pde.grids.tests.test_cartesian_grids import _get_cartesian_grid
 from pde.tools.misc import module_available, skipUnlessModule
 
@@ -478,9 +477,18 @@ def test_generic_derivatives(grid):
         sf_lap += sf._apply_operator(f"d2_d{axis}2", bc="auto_periodic_neumann")
 
     sf_laplace = sf.laplace("auto_periodic_neumann")
-    if isinstance(grid, CartesianGridBase):
+    if isinstance(grid, CartesianGrid):
         # Laplacian is the sum of second derivatives in Cartesian coordinates
         np.testing.assert_allclose(sf_lap.data, sf_laplace.data)
     else:
         # the two deviate in curvilinear coordinates
         assert not np.allclose(sf_lap.data, sf_laplace.data)
+
+
+def test_piecewise_expressions():
+    """test special expressions for creating fields"""
+    grid = CartesianGrid([[0, 4]], 32)
+    field = ScalarField.from_expression(grid, "Piecewise((x**2, x>2), (1+x, x<=2))")
+    x = grid.axes_coords[0]
+    field_data = np.piecewise(x, [x > 2, x <= 2], [lambda x: x**2, lambda x: 1 + x])
+    np.testing.assert_allclose(field.data, field_data)
