@@ -7,6 +7,7 @@ import pytest
 
 from pde import CartesianGrid, PolarSymGrid, ScalarField, Tensor2Field, UnitGrid
 from pde.fields.base import FieldBase
+from pde.fields.tests.fixtures import iter_grids
 
 
 def test_tensors_basic():
@@ -113,29 +114,30 @@ def test_tensor_symmetrize():
     np.testing.assert_allclose(t2.data, ts.data)
 
 
-def test_insert_tensor(example_grid):
+@pytest.mark.parametrize("grid", iter_grids())
+def test_insert_tensor(grid):
     """test the `insert` method"""
-    f = Tensor2Field(example_grid)
+    f = Tensor2Field(grid)
     a = np.random.random(f.data_shape)
 
-    c = tuple(example_grid.point_to_cell(example_grid.get_random_point()))
+    c = tuple(grid.get_random_point(coords="cell"))
     c_data = (Ellipsis,) + c
-    p = example_grid.cell_to_point(c, cartesian=False)
+    p = grid.transform(c, "cell", "grid")
     f.insert(p, a)
-    np.testing.assert_almost_equal(f.data[c_data], a / example_grid.cell_volumes[c])
+    np.testing.assert_almost_equal(f.data[c_data], a / grid.cell_volumes[c])
 
-    f.insert(example_grid.get_random_point(cartesian=False), a)
+    f.insert(grid.get_random_point(coords="grid"), a)
     np.testing.assert_almost_equal(f.integral, 2 * a)
 
     f.data = 0  # reset
-    insert = example_grid.make_inserter_compiled()
-    c = tuple(example_grid.point_to_cell(example_grid.get_random_point()))
+    insert = grid.make_inserter_compiled()
+    c = tuple(grid.get_random_point(coords="cell"))
     c_data = (Ellipsis,) + c
-    p = example_grid.cell_to_point(c, cartesian=False)
+    p = grid.transform(c, "cell", "grid")
     insert(f.data, p, a)
-    np.testing.assert_almost_equal(f.data[c_data], a / example_grid.cell_volumes[c])
+    np.testing.assert_almost_equal(f.data[c_data], a / grid.cell_volumes[c])
 
-    insert(f.data, example_grid.get_random_point(cartesian=False), a)
+    insert(f.data, grid.get_random_point(coords="grid"), a)
     np.testing.assert_almost_equal(f.integral, 2 * a)
 
 
@@ -217,7 +219,7 @@ def test_from_expressions():
     ys = grid.cell_coords[..., 1]
     np.testing.assert_allclose(tf.data[0, 1], 1)
     np.testing.assert_allclose(tf.data[0, 1], 1)
-    np.testing.assert_allclose(tf.data[1, 0], xs ** 2)
+    np.testing.assert_allclose(tf.data[1, 0], xs**2)
     np.testing.assert_allclose(tf.data[1, 1], xs * ys)
 
     # corner case
