@@ -72,6 +72,7 @@ def test_individual_boundaries():
 
         assert isinstance(str(bc), str)
         assert isinstance(repr(bc), str)
+        assert "field" in bc.get_mathematical_representation("field")
         assert bc.rank == 0
         assert bc.homogeneous
         bc.check_value_rank(0)
@@ -92,6 +93,7 @@ def test_individual_boundaries_multidimensional():
 
     assert isinstance(str(bc), str)
     assert isinstance(repr(bc), str)
+    assert "field" in bc.get_mathematical_representation("field")
     assert bc.rank == 1
     assert bc.homogeneous
     assert bc.axis_coord == 2
@@ -310,6 +312,7 @@ def test_expression_bc_operator(dim):
     grid = CartesianGrid([[0, 1]] * dim, 4)
     bc1 = grid.get_boundary_conditions({"value": 1})
     bc2 = grid.get_boundary_conditions({"virtual_point": f"2 - value"})
+    assert "field" in bc2.get_mathematical_representation("field")
 
     field = ScalarField(grid, 1)
 
@@ -325,6 +328,7 @@ def test_expression_bc_value(dim):
     grid = CartesianGrid([[0, 1]] * dim, 4)
     bc1 = grid.get_boundary_conditions({"value": 1})
     bc2 = grid.get_boundary_conditions({"value_expression": "1"})
+    assert "field" in bc2.get_mathematical_representation("field")
 
     field = ScalarField(grid, 1)
 
@@ -340,6 +344,7 @@ def test_expression_bc_derivative(dim):
     grid = CartesianGrid([[0, 1]] * dim, 4)
     bc1 = grid.get_boundary_conditions({"derivative": 0})
     bc2 = grid.get_boundary_conditions({"derivative_expression": "0"})
+    assert "field" in bc2.get_mathematical_representation("field")
 
     field = ScalarField(grid, 1)
 
@@ -360,3 +365,66 @@ def test_getting_registered_bcs():
     """test the functions that return the registered BCs"""
     assert isinstance(registered_boundary_condition_classes(), dict)
     assert isinstance(registered_boundary_condition_names(), dict)
+
+
+@pytest.mark.parametrize("dim", [1, 2])
+@pytest.mark.parametrize("target", ["value", "derivative"])
+def test_user_bcs_numpy(dim, target):
+    """test setting user BCs"""
+    value = np.arange(3) if dim == 2 else 1
+    grid = UnitGrid([3] * dim)
+    bcs = grid.get_boundary_conditions({"type": "user"})
+
+    # use normal method to set BCs
+    f1 = ScalarField(grid)
+    f1.set_ghost_cells(bc={target: value})
+
+    # use user method to set BCs
+    f2 = ScalarField(grid)
+
+    # test whether normal call is a no-op
+    f2._data_full = 3
+    f2.set_ghost_cells(bc=bcs)
+    np.testing.assert_allclose(f2._data_full, 3)
+    f2.set_ghost_cells(bc=bcs, args={"t": 1})
+    np.testing.assert_allclose(f2._data_full, 3)
+    f2._data_full = 0
+
+    # test whether calling setter with user data works properly
+    bcs.set_ghost_cells(f2._data_full, args={target: value})
+
+    np.testing.assert_allclose(f1._data_full, f2._data_full)
+
+
+@pytest.mark.parametrize("dim", [1, 2, 3])
+@pytest.mark.parametrize("target", ["value", "derivative"])
+def test_user_bcs_numba(dim, target):
+    """test setting user BCs"""
+    if dim == 1:
+        value = 1
+    elif dim == 2:
+        value = np.arange(3)
+    elif dim == 3:
+        value = np.arange(9).reshape(3, 3)
+    grid = UnitGrid([3] * dim)
+    bcs = grid.get_boundary_conditions({"type": "user"})
+
+    # use normal method to set BCs
+    f1 = ScalarField(grid)
+    f1.set_ghost_cells(bc={target: value})
+
+    # use user method to set BCs
+    f2 = ScalarField(grid)
+    setter = bcs.make_ghost_cell_setter()
+
+    # test whether normal call is a no-op
+    f2._data_full = 3
+    setter(f2._data_full)
+    np.testing.assert_allclose(f2._data_full, 3)
+    setter(f2._data_full, args={"t": 1})
+    np.testing.assert_allclose(f2._data_full, 3)
+    f2._data_full = 0
+
+    # test whether calling setter with user data works properly
+    setter(f2._data_full, args={target: value})
+    np.testing.assert_allclose(f1._data_full, f2._data_full)
