@@ -36,6 +36,12 @@ class SmoothData1D:
         if self.x.shape != self.y.shape:
             raise ValueError("`x` and `y` must have equal number of elements")
 
+        # only take finite values
+        idx = np.isfinite(self.y)
+        if not np.all(idx):
+            self.x = self.x[idx]
+            self.y = self.y[idx]
+
         if sigma is None:
             self.sigma = float(self.sigma_auto_scale * self.x.ptp() / len(self.x))
         else:
@@ -64,8 +70,12 @@ class SmoothData1D:
         xs = np.ravel(xs)
         scale = 0.5 * self.sigma**-2
 
+        # determine the weights of all input points
         with np.errstate(under="ignore"):
             weight = np.exp(-scale * (self.x[:, None] - xs[None, :]) ** 2)
-            weight /= weight.sum(axis=0)
-        result = np.dot(self.y, weight)
+            weight_sum = weight.sum(axis=0)
+            i = weight_sum > 0
+            weight[..., i] /= weight_sum[i]
+
+        result = self.y @ weight
         return result.reshape(shape)
