@@ -18,7 +18,7 @@ One aim is to allow easy management of inheritance of parameters.
 from __future__ import annotations
 
 import logging
-from typing import Any, Dict, Sequence, Union
+from typing import Any, Dict, Sequence, Type, Union
 
 import numpy as np
 
@@ -66,9 +66,17 @@ class Parameter:
             # check whether the default value is of the correct type
             converted_value = cls(default_value)
             if isinstance(converted_value, np.ndarray):
+                # numpy arrays are checked for each individual value
                 valid_default = np.allclose(converted_value, default_value)
+
             else:
-                valid_default = converted_value == default_value
+                # other values are compared directly. Note that we also check identity
+                # to capture the case where the value is `math.nan`, where the direct
+                # comparison (nan == nan) would evaluate to False
+                valid_default = (
+                    converted_value is default_value or converted_value == default_value
+                )
+
             if not valid_default:
                 logging.warning(
                     "Default value `%s` does not seem to be of type `%s`",
@@ -155,7 +163,7 @@ class Parameterized:
     """a mixin that manages the parameters of a class"""
 
     parameters_default: ParameterListType = []
-    _subclasses: Dict[str, Parameterized] = {}
+    _subclasses: Dict[str, Type[Parameterized]] = {}
 
     def __init__(self, parameters: Dict[str, Any] = None):
         """initialize the parameters of the object
@@ -190,7 +198,8 @@ class Parameterized:
 
         # register the subclasses
         super().__init_subclass__(**kwargs)
-        cls._subclasses[cls.__name__] = cls
+        if cls is not Parameterized:
+            cls._subclasses[cls.__name__] = cls
 
     @classmethod
     def get_parameters(
