@@ -21,6 +21,7 @@ The trackers defined in this module are:
 """
 
 import inspect
+import math
 import os.path
 import sys
 import time
@@ -39,7 +40,7 @@ from ..tools.output import get_progress_bar_class
 from ..tools.parse_duration import parse_duration
 from ..tools.typing import Real
 from .base import FinishedSimulation, InfoDict, TrackerBase
-from .intervals import IntervalData, RealtimeIntervals
+from .interrupts import IntervalData, RealtimeInterrupts
 
 if TYPE_CHECKING:
     import pandas  # @UnusedImport
@@ -48,7 +49,23 @@ if TYPE_CHECKING:
 
 
 class CallbackTracker(TrackerBase):
-    """Tracker calling a function periodically"""
+    """Tracker calling a function periodically
+
+    Example:
+        The callback tracker can be used to check for conditions during the simulation:
+
+        .. code-block:: python
+
+            def check_simulation(state, time):
+                if state.integral < 0:
+                    raise StopIteration
+
+            tracker = CallbackTracker(check_simulation, interval="0:10")
+
+        Adding :code:`tracker` to the simulation will perform a check every 10 real time
+        seconds. If the integral of the entire state falls below zero, the simulation
+        will be aborted.
+    """
 
     @fill_in_docstring
     def __init__(self, func: Callable, interval: IntervalData = 1):
@@ -111,7 +128,7 @@ class ProgressTracker(TrackerBase):
         """
         if interval is None:
             # print every second by default
-            interval = RealtimeIntervals(duration=1)
+            interval = RealtimeInterrupts(duration=1)
 
         super().__init__(interval=interval)
         self.ndigits = ndigits
@@ -174,8 +191,8 @@ class ProgressTracker(TrackerBase):
 
         # limit progress bar to 100%
         controller_info = {} if info is None else info.get("controller", {})
-        t_final = controller_info.get("t_final", -np.inf)
-        t_end = controller_info.get("t_end", -np.inf)
+        t_final = controller_info.get("t_final", -math.inf)
+        t_end = controller_info.get("t_end", -math.inf)
         if t_final >= t_end and self.progress_bar.total:
             self.progress_bar.n = self.progress_bar.total
             self.progress_bar.refresh()
@@ -254,7 +271,7 @@ class PlotTracker(TrackerBase):
         output_file: Optional[str] = None,
         movie: Union[str, Path, "Movie"] = None,
         show: bool = None,
-        max_fps: float = np.inf,
+        max_fps: float = math.inf,
         plot_args: Dict[str, Any] = None,
     ):
         """
@@ -285,7 +302,7 @@ class PlotTracker(TrackerBase):
                 Determines the maximal rate (frames per second) at which the plots are
                 updated in real time during the simulation. Some plots are skipped if
                 the tracker receives data at a higher rate. A larger value (e.g.,
-                `np.inf`) can be used to ensure every frame is drawn, which might
+                `math.inf`) can be used to ensure every frame is drawn, which might
                 penalizes the overall performance.
             plot_args (dict):
                 Extra arguments supplied to the plot call. For example, this can
@@ -461,10 +478,10 @@ class PlotTracker(TrackerBase):
 class LivePlotTracker(PlotTracker):
     """PlotTracker with defaults for live plotting
 
-    The only difference to :class:`PlotTracker` are the changed default values,
-    where output is by default shown on screen and the `interval` is set
-    something more suitable for interactive plotting. In particular, this
-    tracker can be enabled by simply listing 'plot' as a tracker.
+    The only difference to :class:`PlotTracker` are the changed default values, where
+    output is by default shown on screen and the `interval` is set something more
+    suitable for interactive plotting. In particular, this tracker can be enabled by
+    simply listing 'plot' as a tracker.
     """
 
     name = "plot"
@@ -501,8 +518,8 @@ class LivePlotTracker(PlotTracker):
             max_fps (float):
                 Determines the maximal rate (frames per second) at which the plots are
                 updated. Some plots are skipped if the tracker receives data at a higher
-                rate. A larger value (e.g., `np.inf`) can be used to ensure every frame
-                is drawn, which might penalizes the overall performance.
+                rate. A larger value (e.g., `math.inf`) can be used to ensure every
+                frame is drawn, which might penalizes the overall performance.
             plot_args (dict):
                 Extra arguments supplied to the plot call. For example, this can
                 be used to specify axes ranges when a single panel is shown. For
@@ -629,7 +646,7 @@ class DataTracker(CallbackTracker):
 
 
 class SteadyStateTracker(TrackerBase):
-    """Tracker interrupting the simulation once steady state is reached
+    """Tracker aborting the simulation once steady state is reached
 
     Steady state is obtained when the state does not change anymore. This is the case
     when the derivative is close to zero. Concretely, the current state `cur` is
@@ -668,7 +685,7 @@ class SteadyStateTracker(TrackerBase):
                 graphically during the simulation
         """
         if interval is None:
-            interval = RealtimeIntervals(duration=1)
+            interval = RealtimeInterrupts(duration=1)
         super().__init__(interval=interval)
         self.atol = atol
         self.rtol = rtol
@@ -696,8 +713,8 @@ class SteadyStateTracker(TrackerBase):
             # Note that atol and rtol are scaled with dt to make test independent of dt.
             finite = np.isfinite(field.data)  # ignore infinite and nan data
             diff = np.abs(self._last_data[finite] - field.data[finite])
-            diff_abs = diff - self.rtol * self.interval.dt * np.abs(field.data[finite])
-            diff_abs_max = np.max(diff_abs) / self.interval.dt
+            diff_abs = diff - self.rtol * self.interrupt.dt * np.abs(field.data[finite])
+            diff_abs_max = np.max(diff_abs) / self.interrupt.dt
 
             if diff_abs_max <= self.atol:
                 # simulation has converged
@@ -802,7 +819,7 @@ class ConsistencyTracker(TrackerBase):
                 every (real) second.
         """
         if interval is None:
-            interval = RealtimeIntervals(duration=1)
+            interval = RealtimeInterrupts(duration=1)
         super().__init__(interval=interval)
 
     def handle(self, field: FieldBase, t: float) -> None:
