@@ -26,6 +26,27 @@ def _most_severe_exit_code(retcodes: Sequence[int]) -> int:
         return max(retcodes, key=lambda retcode: abs(retcode))
 
 
+def show_config():
+    """show package configuration"""
+    from importlib.machinery import SourceFileLoader
+
+    # imports the package from the package path
+    pde = SourceFileLoader(PACKAGE, f"{PACKAGE_PATH/PACKAGE}/__init__.py").load_module()
+    # obtain the package environment
+    env = pde.environment()
+
+    print(f"{'='*33} CONFIGURATION {'='*32}")
+    for category, data in env.items():
+        if hasattr(data, "items"):
+            print(f"\n{category}:")
+            for key, value in data.items():
+                print(f"    {key}: {value}")
+        else:
+            data_formatted = data.replace("\n", "\n    ")
+            print(f"{category}: {data_formatted}")
+    print("=" * 80)
+
+
 def test_codestyle(*, verbose: bool = True) -> int:
     """run the codestyle tests
 
@@ -91,18 +112,22 @@ def test_types(*, report: bool = False, verbose: bool = True) -> int:
 
 def run_unit_tests(
     runslow: bool = False,
+    runinteractive: bool = False,
     parallel: bool = False,
     coverage: bool = False,
     nojit: bool = False,
+    early: bool = False,
     pattern: str = None,
 ) -> int:
     """run the unit tests
 
     Args:
         runslow (bool): Whether to run the slow tests
+        runinteractive (bool): Whether to run the interactive tests
         parallel (bool): Whether to use multiple processors
         coverage (bool): Whether to determine the test coverage
         nojit (bool): Whether to disable numba jit compilation
+        early (bool): Whether to fail at the first test
         pattern (str): A pattern that determines which tests are ran
 
     Returns:
@@ -110,6 +135,7 @@ def run_unit_tests(
     """
     # modify current environment
     env = os.environ.copy()
+    env["PYTHONPATH"] = str(PACKAGE_PATH) + ":" + env.get("PYTHONPATH", "")
     env["MPLBACKEND"] = "agg"
     if nojit:
         env["NUMBA_DISABLE_JIT"] = "1"
@@ -126,11 +152,18 @@ def run_unit_tests(
         "tests/pytest.ini",  # locate the configuration file
         "-rs",  # show summary of skipped tests
         "-rw",  # show summary of warnings raised during tests
+        "--import-mode=importlib",
     ]
 
-    # allow running slow tests?
+    # allow running slow and interactive tests?
     if runslow:
         args.append("--runslow")
+    if runinteractive:
+        args.append("--runinteractive")
+
+    # fail early if requested
+    if early:
+        args.append("--maxfail=1")
 
     # run tests using multiple cores?
     if parallel:
@@ -199,6 +232,18 @@ def main() -> int:
         default=False,
         help="Also run slow unit tests",
     )
+    group.add_argument(
+        "--runinteractive",
+        action="store_true",
+        default=False,
+        help="Also run interactive unit tests",
+    )
+    group.add_argument(
+        "--showconfig",
+        action="store_true",
+        default=False,
+        help="Show configuration before running tests",
+    )
     group.add_argument(
         "--coverage",
         action="store_true",
@@ -217,6 +262,12 @@ def main() -> int:
         default=False,
         help="Do not use just-in-time compilation of numba",
     )
+    group.add_argument(
+        "--early",
+        action="store_true",
+        default=False,
+        help="Return at first failed test",
+    )
     group.add_argument(
         "--pattern",
         metavar="PATTERN",
@@ -232,7 +283,11 @@ def main() -> int:
 
     # parse the command line arguments
     args = parser.parse_args()
-    run_all = not (args.style or args.types or args.unit)
+    run_all = not (args.style or args.types or args.unit or args.showconfig)
+
+    # show the package configuration
+    if args.showconfig:
+        show_config()
 
     # run the requested tests
     retcodes = []
@@ -247,9 +302,11 @@ def main() -> int:
     if run_all or args.unit:
         retcode = run_unit_tests(
             runslow=args.runslow,
+            runinteractive=args.runinteractive,
             coverage=args.coverage,
             parallel=args.parallel,
             nojit=args.nojit,
+            early=args.early,
             pattern=args.pattern,
         )
         retcodes.append(retcode)
